Function convert
Source pub fn convert<A, B>(transcript: &Transcript<A>) -> Result<Transcript<B>>
Convert a transcript from one harness to another through the Common hub.
ⓘlet codex_session = convert::<ClaudeCode, Codex>(&claude_session)?;
Errors
When A cannot parse its records or B cannot represent the transcript.